==> hc_crud_ceps-0.13.0.crate: hc_crud_ceps-0.13.0/docs/Holochain_Version_Map.md <==
[back to README.md](../README.md)

# Holochain Version Map

This crate's minor version is bumped whenever the HDK version changes.

> The HDK version stopped tracking Holochain after v0.0.114.

| Holochain Version                                                                                  | Commit Date    | Lair Version                                                                                         | `hc_crud_ceps` (this crate)                                                |
|----------------------------------------------------------------------------------------------------|----------------|------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------|
| [`v0.0.100`](https://github.com/holochain/holochain/tree/3bd9181ea35c32993d1550591fd19720b31065f6) | *Apr 20, 2021* | [`v0.0.1-alpha.12`](https://github.com/holochain/lair/tree/2998dd3ad21928115b3a531cbc319e61bc896b78) | N/A                                                                        |
| [`v0.0.101`](https://github.com/holochain/holochain/tree/ea726cc05aa6064c3b8b4f85fddf3e89429f018e) | *Jul 1, 2021*  | [`v0.0.1-alpha.12`](https://github.com/holochain/lair/tree/2998dd3ad21928115b3a531cbc319e61bc896b78) | N/A                                                                        |
| [`v0.0.102`](https://github.com/holochain/holochain/tree/6535292238dc1fbd2b60433a2054f7787e4f060e) | *Jul 29, 2021* | [`v0.0.1-alpha.12`](https://github.com/holochain/lair/tree/2998dd3ad21928115b3a531cbc319e61bc896b78) | N/A                                                                        |
| [`v0.0.103`](https://github.com/holochain/holochain/tree/f3d17d993ad8d988402cc01d73a0095484efbabb) | *Aug 17, 2021* | [`v0.0.3`](https://github.com/holochain/lair/tree/6a9aab37c90566328c13c4d048d1afaf75fc39a9)          | N/A                                                                        |
| [`v0.0.104`](https://github.com/holochain/holochain/tree/d003eb7a45f1d7125c4701332202761721793d68) | *Aug 25, 2021* | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | N/A                                                                        |
| `v0.0.105` (never released)                                                                        | *Sep 1, 2021*  | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | N/A                                                                        |
| [`v0.0.106`](https://github.com/holochain/holochain/tree/b11908875a9f6a09e8939fbf6f45ff658e3d10a6) | *Sep 16, 2021* | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | [`v0.3.1`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.3.1)   |
| [`v0.0.107`](https://github.com/holochain/holochain/tree/221f3424a919224dcf1950d1059e8b88aba08f7b) | *Sep 22, 2021* | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | [`v0.4.0`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.4.0)   |
| [`v0.0.108`](https://github.com/holochain/holochain/tree/cad04aec3fb5f137b2d224ab29dcc204af7b9821) | *Sep 29, 2021* | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | [`v0.5.0`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.5.0)   |
| [`v0.0.109`](https://github.com/holochain/holochain/tree/e5a480ce735beaa8ae7434abdb1b6dc03d487ffa) | *Oct 7, 2021*  | [`v0.0.7`](https://github.com/holochain/lair/tree/bd92b76ad9cc18bc0c0db215e4bea9767c9003cf)          | [`v0.6.1`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.6.1)   |
| `v0.0.110` to  `v0.0.115` skipped                                                                  |                |                                                                                                      |                                                                            |
| [`v0.0.116`](https://github.com/holochain/holochain/tree/9d9a556e8236234bcca64ee33620012c8a6ab095) | *Dec 8, 2021*  | [`v0.1.0`](https://github.com/holochain/lair/tree/0343621e0bfa2a941ecf53363003d1f28b7ef0e6)          | [`v0.13.0`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.13.0) |

==> hc_crud_ceps-0.20.0.crate: hc_crud_ceps-0.20.0/docs/Holochain_Version_Map.md <==
[back to README.md](../README.md)

# Holochain Version Map

This crate's minor version is bumped whenever the HDK version changes.

> The HDK version stopped tracking Holochain after v0.0.114.

| HDK Version                                                                                        | Commit Date    | Lair Version                                                                                         | `hc_crud_ceps` (this crate)                                                |
|----------------------------------------------------------------------------------------------------|----------------|------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------|
| [`v0.0.100`](https://github.com/holochain/holochain/tree/3bd9181ea35c32993d1550591fd19720b31065f6) | *Apr 20, 2021* | [`v0.0.1-alpha.12`](https://github.com/holochain/lair/tree/2998dd3ad21928115b3a531cbc319e61bc896b78) | N/A                                                                        |
| [`v0.0.101`](https://github.com/holochain/holochain/tree/ea726cc05aa6064c3b8b4f85fddf3e89429f018e) | *Jul 1, 2021*  | [`v0.0.1-alpha.12`](https://github.com/holochain/lair/tree/2998dd3ad21928115b3a531cbc319e61bc896b78) | N/A                                                                        |
| [`v0.0.102`](https://github.com/holochain/holochain/tree/6535292238dc1fbd2b60433a2054f7787e4f060e) | *Jul 29, 2021* | [`v0.0.1-alpha.12`](https://github.com/holochain/lair/tree/2998dd3ad21928115b3a531cbc319e61bc896b78) | N/A                                                                        |
| [`v0.0.103`](https://github.com/holochain/holochain/tree/f3d17d993ad8d988402cc01d73a0095484efbabb) | *Aug 17, 2021* | [`v0.0.3`](https://github.com/holochain/lair/tree/6a9aab37c90566328c13c4d048d1afaf75fc39a9)          | N/A                                                                        |
| [`v0.0.104`](https://github.com/holochain/holochain/tree/d003eb7a45f1d7125c4701332202761721793d68) | *Aug 25, 2021* | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | N/A                                                                        |
| `v0.0.105` (never released)                                                                        | *Sep 1, 2021*  | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | N/A                                                                        |
| [`v0.0.106`](https://github.com/holochain/holochain/tree/b11908875a9f6a09e8939fbf6f45ff658e3d10a6) | *Sep 16, 2021* | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | [`v0.3.1`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.3.1)   |
| [`v0.0.107`](https://github.com/holochain/holochain/tree/221f3424a919224dcf1950d1059e8b88aba08f7b) | *Sep 22, 2021* | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | [`v0.4.0`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.4.0)   |
| [`v0.0.108`](https://github.com/holochain/holochain/tree/cad04aec3fb5f137b2d224ab29dcc204af7b9821) | *Sep 29, 2021* | [`v0.0.4`](https://github.com/holochain/lair/tree/d3155ac98ec550c6b5eb097923556958015f9354)          | [`v0.5.0`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.5.0)   |
| [`v0.0.109`](https://github.com/holochain/holochain/tree/e5a480ce735beaa8ae7434abdb1b6dc03d487ffa) | *Oct 7, 2021*  | [`v0.0.7`](https://github.com/holochain/lair/tree/bd92b76ad9cc18bc0c0db215e4bea9767c9003cf)          | [`v0.6.1`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.6.1)   |
| `v0.0.110` to  `v0.0.115` skipped                                                                  |                |                                                                                                      |                                                                            |
| [`v0.0.116`](https://github.com/holochain/holochain/tree/9d9a556e8236234bcca64ee33620012c8a6ab095) | *Dec 8, 2021*  | [`v0.1.0`](https://github.com/holochain/lair/tree/0343621e0bfa2a941ecf53363003d1f28b7ef0e6)          | [`v0.13.0`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.13.0) |
| `v0.0.117` to  `v0.0.119` skipped                                                                  |                |                                                                                                      |                                                                            |
| [`v0.0.120`](https://github.com/holochain/holochain/tree/4a449ee985053f5b8ee0f0688b949bd26bfcb3fc) | *Jan 26, 2022* | [`v0.1.0`](https://github.com/holochain/lair/tree/0343621e0bfa2a941ecf53363003d1f28b7ef0e6)          | [`v0.17.0`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.17.0) |
| `v0.0.121` to  `v0.0.122` skipped                                                                  |                |                                                                                                      |                                                                            |
| [`v0.0.123`](https://github.com/holochain/holochain/tree/3e49d501ce1b74a700d5abae9b8b26021885f012) | *Feb 23, 2022* | [`v0.1.0`](https://github.com/holochain/lair/tree/0343621e0bfa2a941ecf53363003d1f28b7ef0e6)          | [`v0.20.0`](https://github.com/mjbrisebois/rust-hc-crud-ceps/tree/v0.20.0) |
